==> activity-custom-center-api-0.0.6-20180913.043858-1-sources.jar: cn/com/duiba/activity/custom/center/api/params/icbc/IcbcWorkParam.java <==
package cn.com.duiba.activity.custom.center.api.params.icbc;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

/**
 * Created by dugq on 2018/9/5 0005.
 */
public class IcbcWorkParam  implements Serializable {

    private static final long serialVersionUID = 4929203665549952609L;
    /**
     * 作品类型
     */
    private Integer type;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 审核
     */
    private Integer auditStatus;

    /**
     * 分页
     */
    private Integer pageNo;
    /**
     * 分页
     */
    private Integer pageSize;
    /**
     * 分页
     */
    private Integer offset;

    /**
     * 查询列表的用户id， 用于查询点赞记录
     */
    private Long loginId;

    public Long getLoginId() {
        return loginId;
    }

    public void setLoginId(Long loginId) {
        this.loginId = loginId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(Integer auditStatus) {
        this.auditStatus = auditStatus;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getOffset() {
        if(!Objects.isNull(pageNo)){
            return (pageNo-1)*pageSize;
        }
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }
}

==> activity-custom-center-api-0.1.4-sources.jar: cn/com/duiba/activity/custom/center/api/params/icbc/IcbcWorkParam.java <==
package cn.com.duiba.activity.custom.center.api.params.icbc;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

/**
 * Created by dugq on 2018/9/5 0005.
 */
public class IcbcWorkParam  implements Serializable {

    private static final long serialVersionUID = 4929203665549952609L;
    /**
     * 作品类型
     */
    private Integer type;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 审核
     */
    private Integer auditStatus;

    /**
     * 分页
     */
    private Integer pageNo;
    /**
     * 分页
     */
    private Integer pageSize;
    /**
     * 分页
     */
    private Integer offset;

    /**
     * 查询列表的用户id， 用于查询点赞记录
     */
    private String custId;

    public String getCustId() {
        return custId;
    }

    public void setCustId(String custId) {
        this.custId = custId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(Integer auditStatus) {
        this.auditStatus = auditStatus;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getOffset() {
        if(!Objects.isNull(pageNo)){
            return (pageNo-1)*pageSize;
        }
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }
}
